@@ -1,13 +1,17 @@
 """Asynchronous Python client for the IPX800 v5 API."""
 
 from .const import *
+from .counter import Counter
 from .exceptions import (
-    Ipx800CannotConnectError,
-    Ipx800InvalidAuthError,
-    Ipx800RequestError,
+    IPX800CannotConnectError,
+    IPX800InvalidAuthError,
+    IPX800RequestError,
 )
 from .ipx800 import IPX800
 from .ipx800_io import IPX800AnalogInput, IPX800DigitalInput, IPX800Relay
+from .thermostat import Thermostat
+from .x4fp import X4FP, X4FPMode
+from .x4vr import X4VR
 from .x8d import X8D
 from .x8r import X8R
 from .x24d import X24D
@@ -16,16 +20,21 @@ from .xpwm import XPWM
 from .xthl import XTHL
 
 __all__ = [
+    "Counter",
+    "IPX800CannotConnectError",
+    "IPX800InvalidAuthError",
+    "IPX800RequestError",
     "IPX800",
-    "Ipx800CannotConnectError",
-    "Ipx800InvalidAuthError",
-    "Ipx800RequestError",
-    "IPX800Relay",
     "IPX800AnalogInput",
     "IPX800DigitalInput",
+    "IPX800Relay",
+    "Thermostat",
+    "X4FP",
+    "X4FPMode",
+    "X4VR",
     "X8D",
-    "X24D",
     "X8R",
+    "X24D",
     "XDimmer",
     "XPWM",
     "XTHL",
