@@ -230,14 +230,14 @@ class IPX800:
         extensions = [
             x for x in self.extensions_config if x[API_CONFIG_TYPE] == ext_type
         ]
-        return extensions[ext_number][API_CONFIG_PARAMS]
+        return extensions[ext_number - 1][API_CONFIG_PARAMS]
 
     def get_ext_id(self, ext_type: str, ext_number: int) -> int:
         """Return the unique extension id generated by the IPX."""
         extensions = [
             x for x in self.extensions_config if x[API_CONFIG_TYPE] == ext_type
         ]
-        return extensions[ext_number][API_CONFIG_ID]
+        return extensions[ext_number - 1][API_CONFIG_ID]
 
     async def get_ext_states(self, ext_type: str, ext_id: int) -> dict:
         """Return all values of extension."""
@@ -246,12 +246,12 @@ class IPX800:
     def get_obj_config(self, obj_type: str, obj_number: int) -> dict:
         """Return the extension config."""
         extensions = [x for x in self.objects_config if x[API_CONFIG_TYPE] == obj_type]
-        return extensions[obj_number][API_CONFIG_PARAMS]
+        return extensions[obj_number - 1][API_CONFIG_PARAMS]
 
     def get_obj_id(self, obj_type: str, obj_number: int) -> str:
         """Return the unique object id generated by the IPX."""
         objs = [x for x in self.objects_config if x[API_CONFIG_TYPE] == obj_type]
-        return objs[obj_number][API_CONFIG_ID]
+        return objs[obj_number - 1][API_CONFIG_ID]
 
     # Get/Update commands
 
